#!/usr/bin/env python
#
# ESA (C) 2000-2021 
#
# This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
#
#    SAS is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    SAS is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with SAS.  If not, see <http://www.gnu.org/licenses/>.


import pysas.rgsimplot.rgsimplot as rgsimplot

def test_set_ylabel():
    result = rgsimplot.set_ylabel('PHA')
    assert result == 'PHA (Channel)'


def test_set_xlabel():
    result = rgsimplot.set_xlabel('DETX')
    assert result == 'DETX (mm)'


def test_get_observation_details():
    test_data = 'test_data/RGS/spatial_r1.fits'
    result = rgsimplot.getobservationdetails(test_data)
    assert result


def test_general_pdf():
    spatialset = 'test_data/RGS/spatial_r1.fits'
    endispset = 'test_data/RGS/pi_r1.fits'
    srclist = 'test_data/RGS/srclistr1.FIT'

    # rgsimplot spatialset=test_data/RGS/spatial_r1.fits endispset=test_data/RGS/pi_r1.fits srclistset=test_data/RGS/srclistr1.FIT srcidlist=3 withspatialset=yes withendispset=yes withspatialregionset=yes withendispregionset=yes orderlist=1,2 colourmap=plasma plotfile=test_plot norm=log 
    dict_values = dict()
    dict_values.update({'spatialset' : spatialset})
    dict_values.update({'endispset' : endispset})
    dict_values.update({'srcidlist' : 3})
    dict_values.update({'srclistset' : srclist})
    dict_values.update({'withspatialset' : 'yes'})
    dict_values.update({'withendispset' : 'yes'})
    dict_values.update({'withspatialregionset' : 'yes'})
    dict_values.update({'dark_mode' : 'no'})
    dict_values.update({'withendispregionset' : 'yes'})
    dict_values.update({'orderlist' : '1,2'})
    dict_values.update({'colourmap' : 'plasma'})
    dict_values.update({'plotfile' : 'test_plot'})
    dict_values.update({'norm' : 'pow'})
    dict_values.update({'format' : 'PDF'})
    dict_values.update({'gamma' : 0.5})
    dict_values.update({'inverted' : 'no'})
    rgsimplot.run(dict_values)
    assert True
 

def test_general_png():
    spatialset = 'test_data/RGS/spatial_r1.fits'
    endispset = 'test_data/RGS/pi_r1.fits'
    srclist = 'test_data/RGS/srclistr1.FIT'

    # rgsimplot spatialset=test_data/RGS/spatial_r1.fits dark_mode=yes endispset=test_data/RGS/pi_r1.fits srclistset=test_data/RGS/srclistr1.FIT srcidlist=3 withspatialset=yes withendispset=yes withspatialregionset=yes withendispregionset=yes orderlist=1,2 colourmap=plasma plotfile=test_plot norm=log
    dict_values = dict()
    dict_values.update({'spatialset' : spatialset})
    dict_values.update({'endispset' : endispset})
    dict_values.update({'srcidlist' : 3})
    dict_values.update({'srclistset' : srclist})
    dict_values.update({'withspatialset' : 'yes'})
    dict_values.update({'withendispset' : 'yes'})
    dict_values.update({'withspatialregionset' : 'yes'})
    dict_values.update({'withendispregionset' : 'yes'})
    dict_values.update({'orderlist' : '1,2'})
    dict_values.update({'colourmap' : 'plasma'})
    dict_values.update({'plotfile' : 'test_plot'})
    dict_values.update({'dark_mode' : 'yes'})
    dict_values.update({'norm' : 'pow'})
    dict_values.update({'format' : 'png'})
    dict_values.update({'gamma' : 0.5})
    dict_values.update({'inverted' : 'no'})
    rgsimplot.run(dict_values)
    assert True

